@@ -79,6 +79,10 @@ apply_settings (GpsDataLoggerWidget * self)
         my_interval = LOCATION_INTERVAL_20S;
     else if (self->settings->interval == 5)
         my_interval = LOCATION_INTERVAL_30S;
+    else if (self->settings->interval == 6)
+        my_interval = LOCATION_INTERVAL_60S;
+    else if (self->settings->interval == 7)
+        my_interval = LOCATION_INTERVAL_120S;
 
     g_object_set(G_OBJECT (self->control),
                  "preferred-method", my_method,
@@ -254,6 +258,10 @@ settings_dialog_new (GpsDataLoggerWidget * self)
                                       "20 seconds");
     hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (selector),
                                       "30 seconds");
+    hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (selector),
+                                      "60 seconds");
+    hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (selector),
+                                      "120 seconds");
     hildon_picker_button_set_selector(HILDON_PICKER_BUTTON
              (self->pkr_interval), HILDON_TOUCH_SELECTOR (selector));
     gtk_box_pack_start (GTK_BOX (vbox),
